export interface Transaction {
    id?: number;
    amount: number;
    description:string;
    date: string;
    expense: boolean;
    category: string;
    location: string;
}

export type OptionalTransaction = Partial<Transaction>;

class APIService {
    // creates one transaction
    async create(transaction: Transaction) {
        let response = await fetch('/api/transaction', 
        {
            method: 'POST',
            body: JSON.stringify(transaction)
        });
        return await response.json() as Transaction;
    }

    // returns a list of all transacations
    async list(): Promise<Transaction[]> {
        let response = await fetch('/api/transaction');
        let result = (await response.json()) as Transaction[];
        return result;
    }

    // update the list of transactions
    async update(transaction: Transaction) {
        let response = await fetch(`/api/transaction/${transaction.id}`,
        {
            method: 'PATCH',
            body: JSON.stringify(transaction)
        });
        return await response.json() as string;
    }

    // delete a particular transaction
    async delete(id: number) {
        await fetch(`/api/transaction/${id}`,
        {
            method: 'DELETE',
        });
    }

    async get(id: number): Promise<Transaction> {
        let response = await fetch(`/api/transaction/${id}`);
        let result = await response.json() as Transaction;
        return result;
    }
}


export default APIService;