import * as React from "react";
import { Bar } from "react-chartjs-2";
import { Chart, CategoryScale, ArcElement, LinearScale, registerables } from 'chart.js';
import APIService, { Transaction } from "../../APIService";
Chart.register(CategoryScale);
Chart.register(LinearScale);
Chart.register(ArcElement);
Chart.register(...registerables);

import '../../styles/resume.css';


export default function BarChart() {
  const defaultDate = new Date();
  let [date, setDate] = React.useState(defaultDate);
  let [transactions, setTransactions] = React.useState([]);
  

  function next() {
    if (date.getMonth() == 11) {
      setDate(new Date(date.getFullYear() + 1, 0, 1));
    } else {
      setDate(new Date(date.getFullYear(), date.getMonth() + 1, 1));
    }
  }

  function previous() {
    if (date.getMonth() == 0) {
      setDate(new Date(date.getFullYear() - 1, 11, 1));
    } else {
      setDate(new Date(date.getFullYear(), date.getMonth() - 1, 1));
    }
  }

  const getDays = (year, month) => {
    return new Date(year, month+1, 0).getDate();
  };

  React.useEffect(() => {
    apiService.list().then(transactions => setTransactions(transactions.sort((x, y) => {
      let d1 = new Date(x.date);
      let d2 = new Date(y.date);

      return d1.getTime() - d2.getTime();
    })))}, []);

    console.log(transactions)

    transactions = transactions.filter((transaction, i) => {
      let trDate = new Date(transaction.date);
      let trYr =  trDate.getFullYear();
      let trMonth = trDate.getMonth();

      let month = date.getMonth();
      let yr = date.getFullYear();
      return (trYr == yr && month == trMonth);
    })

    console.log(transactions);


  let apiService = new APIService();  
  let myLabels = Array.from({length : getDays(date.getFullYear(), date.getMonth())}, (x,i) => i+1);
  const size = getDays(date.getFullYear(), date.getMonth());

  console.log("Size" + size);
  let values = [...new Array(size)].map(_ => 0);
  console.log("values : ")
  console.log([...values])
  transactions.forEach((transaction) => {
    console.log(transaction.date); 
    let trDate = new Date(transaction.date); 
    let day = trDate.getDate(); 
    console.log("date " + day);
    console.log(transaction.amount);
    console.log("values per day " + values[day])
    if (transaction.expense) {
      values[day] = Number((values[day] - parseInt(transaction.amount)));
    } else {
      values[day] = Number((values[day] + parseInt(transaction.amount)));
    }
    console.log(values);
  })

  const data = {
    labels: myLabels,
    datasets: [{
      label: '',
      data: values,
      backgroundColor: [
        'rgb(255, 99, 132)',
        'rgb(255, 99, 4)',
        'rgb(54, 162, 235)',
        'rgb(199, 58, 58)',
        'rgb(51, 255, 255)',
        'rgb(81, 255, 128)',
        'rgb(242, 211, 8)',
        'rgb(242, 133, 8)',
        'rgb(22, 133, 8)',
      ],
      hoverOffset: 4
    }],
    options: {
      scales: {
        yAxes: [{
          ticks: {
            min: Math.min.apply(this, values) - 5,
            max: Math.max.apply(this, values) + 5,
          }
        }]
      }
    }
  }

  const dateToString = (date: Date) => {
    const months = ["Janvier", "Février", "Mars", "Avril", "Mai", "Juin", "Juillet", "Août", "Septembre", "Octobre", "Novembre", "Décembre"];
    return months[date.getMonth()] + " " + date.getFullYear();
  }

  return <div className='horizontal'>
    <h2>Diagramme du flux monétaire</h2>
    <p>Date : {dateToString(date)}</p>
    <Bar data={data} />
    <button onClick={previous}>Previous</button>
    <button onClick={next}>Next</button>
  </div>
}


