import * as React from "react";
import { Transaction } from "../../APIService";

import "../../styles/transaction.css";
import {
  VersionedOptionalTransaction,
  VersionedTransaction,
} from "./TransactionList";

export default function TransactionComponant(props: {
  index: number;
  transaction: VersionedOptionalTransaction;
  deleteTransaction: (idx: number) => void;
  saveTransaction: (idx: number, transaction: VersionedTransaction) => void;
  isEditing: boolean;
}) {
  const [location, setLocation] = React.useState(props.transaction.location);
  const [description, setDescription] = React.useState(
    props.transaction.description
  );
  const [amount, setAmount] = React.useState(props.transaction.amount);
  const [date, setDate] = React.useState(props.transaction.date);
  const [category, setCategory] = React.useState(props.transaction.category);
  const [expense, setExpense] = React.useState(props.transaction.expense);
  const [version, setVersion] = React.useState(props.transaction.version);

  const [isEditing, setIsEditing] = React.useState(props.isEditing);

  const categoryMap = [
    {
      "value": "auto-detect",
      "label": "Détection automatique",
    },
    {
      "value": "restaurant",
      "label": "Restaurant"
    },
    {
      "value": "bar",
      "label": "Bar"
    },
    {
      "value": "store",
      "label": "Magasin"
    },
    {
      "value": "groceries",
      "label": "Épicerie",
    },
    {
      "value": "sport",
      "label": "Sport",
    },
    {
      "value": "transport",
      "label": "Transport"
    },
    {
      "value": "subscription",
      "label": "Abonnement"
    },
    {
      "value": "education",
      "label": "Éducation"
    },
    {
      "value": "other",
      "label": "Autre"
    }
  ]

  React.useEffect(() => {
    if (version !== props.transaction.version) {
      setCategory(props.transaction.category);
      setVersion(props.transaction.version);
    }
  }, [props.transaction.version]);

  const persist = () => {
    props.saveTransaction(props.index, {
      id: props.transaction.id,
      location,
      description,
      amount,
      date,
      category,
      expense,
      version,
    });
    setIsEditing(false);
  };

  const edit = () => {
    setIsEditing(true);
  };

  return (
    <>
      <section className="flex-column small-margin" id="container">
        <div className="flex-row item" id="">
          {isEditing ? (
            <>
              <div style={{ marginBottom: "10px" }}>
                <label htmlFor="location" style={{ minWidth: "100px" }}><strong>Lieu : </strong></label>
                <input
                  type="text"
                  value={location}
                  onChange={(e) => setLocation(e.target.value)}
                  required
                />
              </div>
              <div style={{ marginBottom: "10px" }}>
                <strong>Description : </strong>
                <label htmlFor="description"></label>
                <input
                  type="text"
                  value={description}
                  onChange={(e) => setDescription(e.target.value)}
                  required
                />
              </div>
              <div style={{ marginBottom: "10px" }}>
                <strong>Categorie : </strong>
                <label htmlFor="category" style={{ minWidth: "100px" }}></label>
                <select value={category} onChange={e => setCategory(e.target.value)}>
                  {categoryMap.map((elem) => (
                    <option value={elem.value}>{elem.label}</option>
                  ))}
                </select>
              </div>
              <div style={{ marginBottom: "10px" }}>
                <strong>Date : </strong>
                <label htmlFor="date" style={{ minWidth: "100px" }}></label>
                <input
                  type="date"
                  value={date}
                  onChange={(e) => setDate(e.target.value)}
                  required
                />
              </div>
              <div>
                <strong>Montant : </strong>
                <label htmlFor="amount"></label>
                <input
                  type="number"
                  value={amount}
                  onChange={(e) => setAmount(Number(e.target.value))}
                  required
                />{" "}
                <strong> $</strong>
              </div>
              <div>
                <strong>Revenu : </strong>{" "}
                <input
                  type="checkbox"
                  value={Number(!expense)}
                  onChange={(e) => setExpense(!e.target.value)}
                />
              </div>
              <div>
                <strong className="icone" onClick={() => persist()}><i className="fa-solid fa-floppy-disk" />Sauvegarder</strong>

              </div>
              <div>
                <strong className="icone" onClick={() => props.deleteTransaction(props.index)}><i className="fa-solid fa-trash-can"></i> Supprimer</strong>
              </div>
            </>
          ) : (
            <>
              <div style={{ marginBottom: "10px" }}>
                <strong>Lieu : </strong>
                {location}
              </div>
              <div style={{ marginBottom: "10px" }}>
                <strong>Description : </strong>
                {description}
              </div>
              <div style={{ marginBottom: "10px" }}>
                <strong>Categorie : </strong>
                {categoryMap.find(cat => cat.value === category).label}
              </div>
              <div style={{ marginBottom: "10px" }}>
                <strong>Date : </strong>
                {date}
              </div>
              <div>
                <strong>Montant : </strong>
                {amount.toFixed(2)} $
              </div>
              <div>
                <strong>Revenu : </strong>{" "}
                <input
                  type="checkbox"
                  disabled
                  readOnly
                  value={Number(!expense)}
                />
              </div>
              <div>
                <strong className="icone" onClick={() => edit()}><i className="fa-solid fa-pencil" /> Modifier</strong>
              </div>
              <div>
                <strong className="icone" onClick={() => props.deleteTransaction(props.index)}><i className="fa-solid fa-trash-can"></i> Supprimer</strong>
              </div>
            </>
          )}
        </div>
      </section>
    </>
  );
}
