import * as React from "react";
import APIService, { OptionalTransaction, Transaction } from "../../APIService";
import TransactionComponant from "./TransactionComponant";

const transactionSort = (a: OptionalTransaction, b: OptionalTransaction) => {
  const dateA = new Date(a.date);
  const dateB = new Date(b.date);

  if (a.date !== b.date) return dateB.getTime() - dateA.getTime();
  if (a.id === undefined && b.id !== undefined) return -1;
  if (a.id !== undefined && b.id === undefined) return 1;
  if (a.id !== b.id) return b.id - a.id;
  return 0;
}

export type VersionedOptionalTransaction = OptionalTransaction & { version: number }
export type VersionedTransaction = Transaction & { version: number }

export default function TransactionList() {
  const apiService = new APIService();
  const [transactions, setTransactions] = React.useState<VersionedOptionalTransaction[]>(
    []
  );

  React.useEffect(() => {
    apiService.list().then((transactions) => setTransactions(transactions.map(tr => ({ ...tr, version: 0 })).sort(transactionSort)));
  }, []);

  const deleteTransaction = (idx: number) => {
    const transaction = transactions.splice(idx, 1)[0];
    if (transaction.id !== undefined) {
      apiService.delete(transaction.id);
    }
    setTransactions(transactions.slice());
  };

  const saveTransaction = (idx: number, transaction: VersionedTransaction) => {
    transactions[idx] = transaction;
    if (transaction.id === undefined) apiService.create(transaction).then(result => {
      transactions[idx].category = result.category;
      transactions[idx].id = result.id;
      transactions[idx].version++;
      setTransactions(transactions.slice().sort(transactionSort));
    });
    else apiService.update(transaction).then(category => {
      transactions[idx].category = category;
      transactions[idx].version++;
      setTransactions(transactions.slice().sort(transactionSort));
    })
  }

  return (
    <>
      <div>
        <h1>
          Mes transactions
          <strong onClick={() => {
            setTransactions([{ expense: true, category: 'auto-detect', version: 0, amount: 0, date: new Date().toISOString().split('T')[0] }, ...transactions]);
          }} className="icone" id="btn-ajouter" style={{ marginLeft: "20px", paddingRight: "5px" }}> <i className="fa-solid fa-plus" /> Ajouter </strong>
        </h1>
      </div>
      <div style={{ display: "flex", flexDirection: "column", flexGrow: 1 }}>
        {transactions.map((transaction, index) => {
          return (
            <TransactionComponant
              key={transaction.id}
              index={index}
              deleteTransaction={deleteTransaction}
              saveTransaction={saveTransaction}
              transaction={transaction}
              isEditing={transaction.id === undefined}
            />
          );
        })}
      </div>
    </>
  );
}
