<?php

namespace App\Controller;

use App\Form\UserCreateType;
use App\Entity\User;
use Doctrine\Persistence\ManagerRegistry;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\PasswordHasher\Hasher\UserPasswordHasherInterface;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Validator\Constraints\UserPassword;
use Symfony\Component\Security\Http\Authentication\AuthenticationUtils;

class HomeController extends AbstractController
{
    #[Route("/", name: 'login')]
    public function connection(Request $request, ManagerRegistry $doctrine, AuthenticationUtils $authenticationUtils, UserPasswordHasherInterface $passwordHasher): Response
    {
        if ($this->getUser() != null)
        {
            return $this->redirectToRoute('app_transaction');
        }
        $error = $authenticationUtils->getLastAuthenticationError();
        $lastUsername = $authenticationUtils->getLastUsername();
        $entityManager = $doctrine->getManager();

        $user = new User();
        $signUpForm = $this->createForm(UserCreateType::class, $user);
        
        $signUpForm->handleRequest($request);
        if ($signUpForm->isSubmitted() && $signUpForm->isValid()) {
            $user = $signUpForm->getData();

            $plaintextPassword = $user->getPassword();
            $hashedPassword = $passwordHasher->hashPassword(
                $user,
                $plaintextPassword
            );
            $user->setPassword($hashedPassword);

            $entityManager->persist($user);
            $entityManager->flush();

            $this->addFlash("success", "Le compte a été créé avec succès. Vous pouvez vous connecter");

            return $this->redirectToRoute('login');
        }

        return $this->render('connection.html.twig', [
            'form' => $signUpForm,
            'last_username' => $lastUsername,
            'error' => $error,
        ]);
    }

    #[Route("/login", name: 'login_check')]
    public function loginCheck()
    {
        return $this->redirectToRoute('login');
    }

    #[Route("/logout", name: "app_logout")]
    public function logout()
    {
        // controller can be blank: it will never be called!
        throw new \Exception('Don\'t forget to activate logout in security.yaml');
    }
}

