<?php

namespace App\DataFixtures;

use App\Entity\Transaction;
use App\Entity\User;
use Doctrine\Bundle\FixturesBundle\Fixture;
use Doctrine\Persistence\ObjectManager;
use Symfony\Component\PasswordHasher\Hasher\UserPasswordHasherInterface;

class AppFixtures extends Fixture
{
    private UserPasswordHasherInterface $passwordHasher;

    public function __construct(UserPasswordHasherInterface $passwordHasher)
    {
        $this->passwordHasher = $passwordHasher;
    }

    public function load(ObjectManager $manager): void
    {
        $user = new User();
        $user->setName("admin");
        $user->setPassword($this->passwordHasher->hashPassword($user, "password"));
        $manager->persist($user);

        $locations = Array("Metro Cote des Neiges", "Aldo", "Amir", "Bath&BodyWorks", "bento", "David's Tea", "Decathlon", "Dynamite", "Ernest", "Foot Locker", "EBGames", "Garage", "Globo", "Jean Coutu", "Jugo Juice", "La Cremiere", "La Vie en Rose", "Laura Secord", "Levi's", "Lindt", "lululemon", "Mobile Klinik", "Old Navy", "Pandora", "Reitmans", "Canadian Tire", "RW&CO", "SAQ", "Sephora", "Subway", "Thai Express", "The Source", "Tour de jeux", "UniQlo", "Valentine", "Yves Rocher");
        $categories = Array("restaurant", "bar", "store", "groceries", "sport", "transport", "subscription");
        $nbTransactionsToGenerate = rand(3, count($locations) - 1);
        for ($i = 0; $i < $nbTransactionsToGenerate; $i++)
        {
            $transaction = new Transaction();
            $nbCatToGen = rand(0, count($categories) - 1);
            $transaction->setLocation($locations[rand(0, $nbTransactionsToGenerate)]);
            $transaction->setDescription("stores");
            $transaction->setAmount(rand(5, 500));
            $transaction->setCategory($categories[$nbCatToGen]);
            $date = Array("2023-01-", "2022-12-");
            $ranDate = rand(0, 1);
            $day = rand(1, 31);
            $transaction->setDate(new \DateTime($date[$ranDate] . strval($day)));
            $manager->persist($transaction);
            $user->addTransaction($transaction);
        }

        $manager->flush();
    }
}
