<?php
namespace App\Service;

class CategoryService {
    private \CurlHandle $ch;
    private string $wikipediaBaseUrl = "https://en.wikipedia.org/w/api.php";
    private string $baseUrl = "https://maps.googleapis.com/maps/api/place/nearbysearch/json";
    private $categoriesWhitelist = ["restaurant", "bar", "store"];
    private $categoriesMap = [
        "university" => "education",
        "supermarket" => "groceries",
        "grocery_or_supermarket" => "groceries",
        "bicycle_store" => "sport",
        "cafe" => "restaurant",
        "transit_station" => "transport",
        "airport" => "transport",
        "gas_station" => "transport",
        "car_dealership" => "transport",
    ];
    private $wikipediaMap = [
        "e-commerce" => "store",
        "streaming" => "subscription"
    ];
    private $wikipediaWhitelist = ["subscription"];

    private string $apiKey;

    public function __construct(string $apiKey) {
        $this->ch = curl_init();
        $this->apiKey = $apiKey;
    }

    public function __destruct() {
        curl_close($this->ch);
    }

    private function wikipediaFind(string $description): string {
        $url = $this->wikipediaBaseUrl . "?" . http_build_query([
            "action" => "query",
            "list" => "search",
            "srsearch" => $description,
            "format" => "json"
        ]);
        curl_setopt($this->ch, CURLOPT_URL, $url);
        curl_setopt($this->ch, CURLOPT_RETURNTRANSFER, true);
        $result = json_decode(curl_exec($this->ch), true);
        if (!is_array($result) || count($result["query"]["search"]) == 0) return "other";
        $text = $result["query"]["search"][0]["snippet"];
        return $this->mapCategories(explode(" ", $text), "wikipedia");
    }

    private function searchPlace(string $description) {
        $url = $this->baseUrl . "?" . http_build_query([
            "keyword" => $description,
            "location" => "45.5041869,-73.6136041",
            // "location" => "48.855660,2.359730",
            "radius" => 150000,
            "key" => "AIzaSyC_4Qk1BHLzFnXJR5raGVWJB9bmrNiOFQw"
        ]);
        curl_setopt($this->ch, CURLOPT_URL, $url);
        curl_setopt($this->ch, CURLOPT_RETURNTRANSFER, true);
        return curl_exec($this->ch);
    }

    private function mapCategories($categories, string $type) {
        if ($type == "google") {
            $map = $this->categoriesMap;
            $whitelist = $this->categoriesWhitelist;
        } else if($type === "wikipedia") {
            $map = $this->wikipediaMap;
            $whitelist = $this->wikipediaWhitelist;
        }
        foreach ($map as $key => $value) {
            if (in_array($key, $categories)) {
                return $value;
            }
        }

        foreach($whitelist as $category) {
            if (in_array($category, $categories)) {
                return $category;
            }
        }

        return "other";
    }

    private function getCategoryGoogle(string $description): string {
        $result = json_decode($this->searchPlace($description), true);
        if (!is_array($result)) return "other";
        if (count($result["results"]) == 0) return "other";
        return $this->mapCategories($result["results"][0]["types"], "google");
    }

    public function getCategory(string $description): string {
        $googleResult = $this->getCategoryGoogle($description);
        $wikipediaResult = $this->wikipediaFind($description);
        return $wikipediaResult !== "other" ? $wikipediaResult : $googleResult;
    }
}